@@ -35,6 +35,7 @@
 #endif
 
 #include <queue>
+#include <vector>
 #include <stack>
 #include <string>
 #include <cstdlib>
@@ -91,9 +92,9 @@ public:
     
     bool        mAllowOverlap;
     
-    using ContainerStack_t = std::deque<AST::ASTrepContainer*>;
+    using ContainerStack_t = std::vector<AST::ASTrepContainer*>;
     ContainerStack_t    mContainerStack;
-    std::deque<int>     mStackStack;
+    std::vector<int>     mStackStack;
     void                push_repContainer(AST::ASTrepContainer& c);
     void                pop_repContainer(AST::ASTreplacement* r);
     void                push_rep(AST::ASTreplacement* r, bool global = false);
@@ -115,6 +116,7 @@ public:
     
     int             StringToShape(const std::string& name, const yy::location& loc,
                                   bool colonsAllowed);
+    const char*     getUniqueFile(const std::string* base, const std::string* file);
     std::string     ShapeToString(int shape);
     static const std::string&
                     FlagToString(int flag);
@@ -161,6 +163,7 @@ public:
     void            CheckConfig(AST::ASTdefine* cfg);
     void            inColor();
     void            timeWise();
+    void            blended();
     bool            isMyBuilder() const noexcept;
     bool            impure() const noexcept;
 };
