@@ -122,7 +122,7 @@ int Variation::random(int letters)
     if (!seeded) {
         std::random_device rd;
         Rand64::result_type seed = rd();
-        if (sizeof(std::random_device::result_type) < sizeof(Rand64::result_type))
+        if constexpr (sizeof(std::random_device::result_type) < sizeof(Rand64::result_type))
             seed = (seed << 32) | rd();
         Rand64::Seed(seed);
         seeded = true;
